ScheduleInformation class

Represents the schedule information for an individual or a resource.

Each instance holds information about the schedule ID, availability view, schedule items, and working hours.

Constructors

ScheduleInformation({String? scheduleId, String? availabilityView, List<ScheduleItem>? scheduleItems, WorkingHours? workingHours})
Creates a new instance of ScheduleInformation.
ScheduleInformation.fromJson(Map<String, dynamic> json)
Creates a new instance of ScheduleInformation from a JSON object.
factory

Properties

availabilityView → String?
A string representing the availability view of the calendar.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scheduleId → String?
The identifier for the schedule.
final
scheduleItems → List<ScheduleItem>?
A list of ScheduleItem objects representing the items on the schedule.
final
workingHours → WorkingHours?
A WorkingHours object representing the working hours for the schedule.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited