File class

Represents file metadata in Microsoft Graph API.

Annotations
  • @JsonSerializable.new()

Constructors

File({String? mimeType, Hashes? hashes})
Creates a new File instance.
File.fromJson(Map<String, dynamic> json)
Creates a File instance from JSON data.
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
hashes → Hashes?
Hash value of the file content, if available.
final
mimeType → String?
Properties of the file, including mimetype.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Converts this File instance to JSON data.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited