ItemReference class

Represents a reference to another item in the drive.

Annotations
  • @JsonSerializable.new()

Constructors

ItemReference({String? driveId, String? id, String? path})
Creates a new ItemReference instance.
ItemReference.fromJson(Map<String, dynamic> json)
Creates an ItemReference instance from JSON data.
factory

Properties

driveId → String?
The unique identifier of the drive.
final
hashCode → int
The hash code for this object.
no setterinherited
id → String?
The unique identifier of the item.
final
path → String?
The path of the item from the root.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Converts this ItemReference instance to JSON data.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited