Attachment class

Represents a message attachment.

Annotations
  • @JsonSerializable.new()

Constructors

Attachment({String? id, String? name, String? contentType, int? size, bool? isInline, DateTime? lastModifiedDateTime, String? contentId, String? contentBytes})
Attachment.empty()
const
Attachment.fromJson(Map<String, dynamic> json)
factory

Properties

contentBytes → String?
The base64-encoded contents of the file if the attachment is a file.
final
contentId → String?
The attachment's content ID for inline attachments.
final
contentType → String?
The attachment's MIME type.
final
hashCode → int
The hash code for this object.
no setterinherited
id → String?
The attachment ID.
final
isInline → bool?
When true, indicates the attachment is an inline attachment and appears directly in the body of the message.
final
lastModifiedDateTime → DateTime?
The date and time when the attachment was last modified.
final
name → String?
The attachment name.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → int?
Size of the attachment in bytes.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited