Room class

Represents a room in the Microsoft Graph API.

This class encapsulates various properties of a room, such as its id, email address, display name, address, geo-coordinates, and more.

Constructors

Room({String? id, String? emailAddress, String? displayName, Address? address, GeoCoordinates? geoCoordinates, String? phone, String? nickname, String? label, int? capacity, String? building, int? floorNumber, bool? isManaged, bool? isWheelChairAccessible, String? bookingType, List<String>? tags, String? audioDeviceName, String? videoDeviceName, String? displayDevice})
Creates a new instance of Room.
Room.fromJson(Map<String, dynamic> json)
Creates a new instance of Room from a JSON object.
factory

Properties

address → Address?
The physical address of the room.
final
audioDeviceName → String?
The name of the audio device in the room.
final
bookingType → String?
The booking type of the room.
final
building → String?
The building where the room is located.
final
capacity → int?
The capacity of the room, i.e., the number of people it can accommodate.
final
displayDevice → String?
The name of the display device in the room.
final
displayName → String?
The display name of the room.
final
emailAddress → String?
The email address of the room.
final
floorNumber → int?
The floor number where the room is located.
final
geoCoordinates → GeoCoordinates?
The geographical coordinates of the room.
final
hashCode → int
The hash code for this object.
no setterinherited
id → String?
The unique identifier of the room.
final
isManaged → bool?
Indicates if the room is managed.
final
isWheelChairAccessible → bool?
Indicates if the room is accessible by wheelchair.
final
label → String?
The label of the room.
final
nickname → String?
The nickname of the room.
final
phone → String?
The phone number of the room.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tags → List<String>?
The tags associated with the room.
final
videoDeviceName → String?
The name of the video device in the room.
final

Methods

copyWith({String? id, String? emailAddress, String? displayName, Address? address, GeoCoordinates? geoCoordinates, String? phone, String? nickname, String? label, int? capacity, String? building, int? floorNumber, bool? isManaged, bool? isWheelChairAccessible, String? bookingType, List<String>? tags, String? audioDeviceName, String? videoDeviceName, String? displayDevice}) → Room
Creates a copy of this Room but with the given fields replaced with the new values.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited